@@ -2,10 +2,7 @@ from django.http import HttpResponseForbidden
 from django.contrib.auth import authenticate, login
 from django.views.decorators.csrf import csrf_exempt
 
-try:
-    from functools import wraps
-except ImportError:
-    from django.utils.functional import wraps # Python 2.4 fallback
+from functools import wraps
 
 def token_required(view_func):
     """Decorator which ensures the user has provided a correct user and token pair."""
@@ -13,13 +10,26 @@ def token_required(view_func):
     @csrf_exempt
     @wraps(view_func)
     def _wrapped_view(request, *args, **kwargs):
-        user = request.REQUEST.get('user')
-        token = request.REQUEST.get('token')
+        user = None
+        token = None
+        basic_auth = request.META.get('HTTP_AUTHORIZATION')
+
+        if basic_auth:
+            auth_method, auth_string = basic_auth.split(' ', 1)
+
+            if auth_method.lower() == 'basic':
+                auth_string = auth_string.strip().decode('base64')
+                user, token = auth_string.split(':', 1)
+
+        if not (user and token):
+            user = request.REQUEST.get('user')
+            token = request.REQUEST.get('token')
 
         if user and token:
             user = authenticate(pk=user, token=token)
             if user:
                 login(request, user)
                 return view_func(request, *args, **kwargs)
+
         return HttpResponseForbidden()
     return _wrapped_view
